@@ -6,6 +6,7 @@ import shutil
 
 from sys import platform
 from glob import glob
+from pathlib import Path
 from anasymod.files import get_full_path, mkdir_p
 from anasymod.util import vivado_search_key
 from os import environ as env
@@ -58,6 +59,9 @@ class EmuConfig:
         # Vivado configuration
         self.vivado_config = VivadoConfig(parent=self)
 
+        # XSCT configuration
+        self.xsct_config = XSCTConfig(parent=self)
+
         # GtkWave configuration
         self.gtkwave_config = GtkWaveConfig(parent=self)
 
@@ -102,6 +106,8 @@ class EmuConfig:
             return ZC702()
         elif self.cfg.board_name == BoardNames.ZC706:
             return ZC706()
+        elif self.cfg.board_name == BoardNames.ZCU102:
+            return ZCU102()
         elif self.cfg.board_name == BoardNames.ZCU106:
             return ZCU106()
         elif self.cfg.board_name == BoardNames.ARTY_200T_CUSTOM_LIDAR:
@@ -118,12 +124,17 @@ class VivadoConfig():
         # set project name
         self.project_name = 'prj'
         # intermediate variables for generic Xilinx path
+        self.hints = []
+        self.hints += [lambda: os.path.join(env['VIVADO_INSTALL_PATH'], 'bin')]
         if platform in {'win32', 'cygwin'}:
-            xilinx_version_path = parent.cfg_dict['TOOLS_xilinx']
-            xilinx_version = "20" + ".".join(xilinx_version_path.split(".")[0:2]).split("-")[1]
-        # set path to vivado binary
-        self.hints = [lambda: os.path.join(env['VIVADO_INSTALL_PATH'], 'bin'),
-                      lambda: os.path.join(parent.cfg_dict['INICIO_TOOLS'], xilinx_version_path, "Vivado", xilinx_version, "bin" ),]
+            try:
+                xilinx_version_path = parent.cfg_dict['TOOLS_xilinx']
+                xilinx_version = "20" + ".".join(xilinx_version_path.split(".")[0:2]).split("-")[1]
+                self.hints += [
+                    lambda: os.path.join(parent.cfg_dict['INICIO_TOOLS'], xilinx_version_path, "Vivado", xilinx_version, "bin")
+                ]
+            except:
+                print('Skipping INICIO_TOOLS hint for Vivado.')
         # lsf options for tcl mode of Vivado
         self.lsf_opts_ls = ''
         self.lsf_opts = parent.cfg.lsf_opts
@@ -175,6 +186,79 @@ class VivadoConfig():
             self._version_number = int(self._version_number)
         return self._version_number
 
+class XSCTConfig():
+    def __init__(self, parent: EmuConfig, xsct=None, version=None,
+                 version_year=None, version_number=None, xsct_install_dir=None):
+        # save reference to parent config
+        self.parent = parent
+
+        # set project name
+        self.project_name = 'prj'
+        # intermediate variables for generic Xilinx path
+        self.hints = []
+        self.hints += [lambda: os.path.join(env['XSCT_INSTALL_PATH'], 'bin')]
+        if platform in {'win32', 'cygwin'}:
+            try:
+                xilinx_version_path = parent.cfg_dict['TOOLS_xilinx']
+                xilinx_version = "20" + ".".join(xilinx_version_path.split(".")[0:2]).split("-")[1]
+                self.hints += [
+                    lambda: os.path.join(parent.cfg_dict['INICIO_TOOLS'], xilinx_version_path, "SDK", xilinx_version, "bin")
+                ]
+            except:
+                print('Skipping INICIO_TOOLS hint for XSCT.')
+        # lsf options for tcl mode of Vivado
+        self.lsf_opts_ls = ''
+        self.lsf_opts = parent.cfg.lsf_opts
+        if platform in {'linux', 'linux2'}:
+            sorted_dirs = sorted(glob('/tools/Xilinx/Vivado/*.*'), key=vivado_search_key)
+            self.hints.extend(lambda: os.path.join(dir_, 'bin') for dir_ in sorted_dirs)
+            if 'CAMINO' in os.environ:
+                self.lsf_opts = "-eh_ram 70000 -eh_ncpu 8 -eh_ui inicio_batch"
+                self.lsf_opts_ls = "-eh_ram 70000 -eh_ncpu 8 -eh_dispatch LS_SHELL"
+
+        self._xsct = xsct
+        self._xsct_install_dir = xsct_install_dir
+
+        # version, year, number
+        self._version = version
+        self._version_year = version_year
+        self._version_number = version_number
+
+        # set various project options
+        self.num_cores = multiprocessing.cpu_count()
+
+    @property
+    def xsct(self):
+        if self._xsct is None:
+            self._xsct = find_tool(name='xsct', hints=self.hints)
+        return self._xsct
+
+    @property
+    def xsct_install_dir(self):
+        if self._xsct_install_dir is None:
+            self._xsct_install_dir = Path(self.xsct).resolve().parent.parent
+        return self._xsct_install_dir
+
+    @property
+    def version(self):
+        if self._version is None:
+            self._version = pathlib.Path(self.xsct).parent.parent.name
+        return self._version
+
+    @property
+    def version_year(self):
+        if self._version_year is None:
+            self._version_year = re.match(r'(\d+)\.(\d+)', self.version).groups()[0]
+            self._version_year = int(self._version_year)
+        return self._version_year
+
+    @property
+    def version_number(self):
+        if self._version_number is None:
+            self._version_number = re.match(r'(\d+)\.(\d+)', self.version).groups()[1]
+            self._version_number = int(self._version_number)
+        return self._version_number
+
 class XceliumConfig():
     def __init__(self, parent: EmuConfig, xrun=None):
         # save reference to parent config
@@ -340,6 +424,17 @@ class Config(BaseConfig):
             sometimes has bugs, particularly when more complex Verilog features like hierarchical references and
             interfaces are used."""
 
+        self.vivado_stack = None
+        """ type(int) : Stack size used by Vivado.  If you are getting an error during synthesis that
+            looks like "Segmentation fault "$RDI_PROG"", try setting this to 2000 or higher
+            (https://www.xilinx.com/support/answers/64434.html)."""
+
+        self.no_time_manager = False
+        """ type(bool) : If True, do not instantiate the emu_clk generator, default oscillator,
+            time manager, time control signals, and instead simply wire emu_clk_2x directly
+            to emu_clk.  This can help the design run at higher frequencies, if no time management
+            is required. """
+
 def find_tool(name, hints=None, sys_path_hint=True):
     # set defaults
     if hints is None:
