@@ -4,10 +4,12 @@ from anasymod.viewer.viewer import Viewer
 from anasymod.util import call
 
 class GtkWaveViewer(Viewer):
-    def view(self):
+    def view(self, result_file=None):
+        vcd_path = result_file if result_file is not None else self.target.cfg.vcd_path
+
         # build command
-        if os.path.isfile(self.target.cfg.vcd_path):
-            cmd = [self.cfg.gtkwave_config.gtkwave, self.target.cfg.vcd_path]
+        if os.path.isfile(vcd_path):
+            cmd = [self.cfg.gtkwave_config.gtkwave, vcd_path]
             cmd[1:1] = self.cfg.gtkwave_config.lsf_opts.split()
             # add waveform file if it exists
             if self.cfg.gtkwave_config.gtkw_config is not None:
@@ -17,4 +19,4 @@ class GtkWaveViewer(Viewer):
             # run command
             call(cmd)
         else:
-            raise Exception(f'ERROR: Result file: {self.target.cfg.vcd_path} does not exist; cannot open waveforms!')
\ No newline at end of file
+            raise Exception(f'ERROR: Result file: {vcd_path} does not exist; cannot open waveforms!')
\ No newline at end of file
